/* SerializablePropertyFloatTest.c generated by valac 0.44.3, the Vala compiler
 * generated from SerializablePropertyFloatTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; tab-width: 2 -*- */

#include <glib-object.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>
#include <float.h>
#include <math.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_PROPERTY_FLOAT_TEST (serializable_property_float_test_get_type ())
#define SERIALIZABLE_PROPERTY_FLOAT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_PROPERTY_FLOAT_TEST, SerializablePropertyFloatTest))
#define SERIALIZABLE_PROPERTY_FLOAT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_PROPERTY_FLOAT_TEST, SerializablePropertyFloatTestClass))
#define IS_SERIALIZABLE_PROPERTY_FLOAT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_PROPERTY_FLOAT_TEST))
#define IS_SERIALIZABLE_PROPERTY_FLOAT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_PROPERTY_FLOAT_TEST))
#define SERIALIZABLE_PROPERTY_FLOAT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_PROPERTY_FLOAT_TEST, SerializablePropertyFloatTestClass))

typedef struct _SerializablePropertyFloatTest SerializablePropertyFloatTest;
typedef struct _SerializablePropertyFloatTestClass SerializablePropertyFloatTestClass;
typedef struct _SerializablePropertyFloatTestPrivate SerializablePropertyFloatTestPrivate;

#define SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE (serializable_property_float_test_float_node_get_type ())
#define SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE, SerializablePropertyFloatTestFloatNode))
#define SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE, SerializablePropertyFloatTestFloatNodeClass))
#define SERIALIZABLE_PROPERTY_FLOAT_TEST_IS_FLOAT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE))
#define SERIALIZABLE_PROPERTY_FLOAT_TEST_IS_FLOAT_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE))
#define SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE, SerializablePropertyFloatTestFloatNodeClass))

typedef struct _SerializablePropertyFloatTestFloatNode SerializablePropertyFloatTestFloatNode;
typedef struct _SerializablePropertyFloatTestFloatNodeClass SerializablePropertyFloatTestFloatNodeClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _SerializablePropertyFloatTestFloatNodePrivate SerializablePropertyFloatTestFloatNodePrivate;
enum  {
	SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_0_PROPERTY,
	SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_FLOAT_VALUE_PROPERTY,
	SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_NAME_PROPERTY,
	SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_NUM_PROPERTIES
};
static GParamSpec* serializable_property_float_test_float_node_properties[SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_NUM_PROPERTIES];
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializablePropertyFloatTest {
	GXmlTest parent_instance;
	SerializablePropertyFloatTestPrivate * priv;
};

struct _SerializablePropertyFloatTestClass {
	GXmlTestClass parent_class;
};

struct _SerializablePropertyFloatTestFloatNode {
	GXmlSerializableObjectModel parent_instance;
	SerializablePropertyFloatTestFloatNodePrivate * priv;
};

struct _SerializablePropertyFloatTestFloatNodeClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializablePropertyFloatTestFloatNodePrivate {
	GXmlSerializableFloat* _float_value;
	gchar* _name;
};

static gpointer serializable_property_float_test_parent_class = NULL;
static gint SerializablePropertyFloatTestFloatNode_private_offset;
static gpointer serializable_property_float_test_float_node_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_property_float_test_get_type (void) G_GNUC_CONST;
void serializable_property_float_test_add_tests (void);
static void __lambda243_ (void);
GType serializable_property_float_test_float_node_get_type (void) G_GNUC_CONST;
SerializablePropertyFloatTestFloatNode* serializable_property_float_test_float_node_new (void);
SerializablePropertyFloatTestFloatNode* serializable_property_float_test_float_node_construct (GType object_type);
static void ___lambda243__gtest_func (void);
static void __lambda244_ (void);
void serializable_property_float_test_float_node_set_float_value (SerializablePropertyFloatTestFloatNode* self,
                                                                  GXmlSerializableFloat* value);
GXmlSerializableFloat* serializable_property_float_test_float_node_get_float_value (SerializablePropertyFloatTestFloatNode* self);
static void ___lambda244__gtest_func (void);
static void __lambda245_ (void);
static void ___lambda245__gtest_func (void);
static void __lambda246_ (void);
static void ___lambda246__gtest_func (void);
static void __lambda247_ (void);
static void ___lambda247__gtest_func (void);
SerializablePropertyFloatTest* serializable_property_float_test_new (void);
SerializablePropertyFloatTest* serializable_property_float_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static gchar* serializable_property_float_test_float_node_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_property_float_test_float_node_real_to_string (GXmlSerializableObjectModel* base);
static gboolean serializable_property_float_test_float_node_real_property_use_nick (GXmlSerializableObjectModel* base);
const gchar* serializable_property_float_test_float_node_get_name (SerializablePropertyFloatTestFloatNode* self);
void serializable_property_float_test_float_node_set_name (SerializablePropertyFloatTestFloatNode* self,
                                                           const gchar* value);
static void serializable_property_float_test_float_node_finalize (GObject * obj);
static void _vala_serializable_property_float_test_float_node_get_property (GObject * object,
                                                                     guint property_id,
                                                                     GValue * value,
                                                                     GParamSpec * pspec);
static void _vala_serializable_property_float_test_float_node_set_property (GObject * object,
                                                                     guint property_id,
                                                                     const GValue * value,
                                                                     GParamSpec * pspec);

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result = NULL;
#line 1516 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1517 "glib-2.0.vapi"
	result = self;
#line 1517 "glib-2.0.vapi"
	return result;
#line 161 "SerializablePropertyFloatTest.c"
}

static void
__lambda243_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializablePropertyFloatTestFloatNode* bn = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp0_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		GXmlElement* element = NULL;
		GXmlNode* _tmp8_;
		GXmlNode* _tmp9_;
		GXmlElement* _tmp10_;
		GXmlNode* b = NULL;
		GXmlNode* _tmp11_;
		GXmlNode* s = NULL;
		GXmlNode* _tmp12_;
#line 41 "SerializablePropertyFloatTest.vala"
		_tmp0_ = serializable_property_float_test_float_node_new ();
#line 41 "SerializablePropertyFloatTest.vala"
		bn = _tmp0_;
#line 42 "SerializablePropertyFloatTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 42 "SerializablePropertyFloatTest.vala"
		doc = _tmp1_;
#line 43 "SerializablePropertyFloatTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) bn, (GXmlNode*) doc, &_inner_error0_);
#line 43 "SerializablePropertyFloatTest.vala"
		_tmp3_ = _tmp2_;
#line 43 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (_tmp3_);
#line 43 "SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 43 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc);
#line 43 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (bn);
#line 207 "SerializablePropertyFloatTest.c"
			goto __catch297_g_error;
		}
#line 44 "SerializablePropertyFloatTest.vala"
		_tmp4_ = gxml_gnode_to_string ((GXmlGNode*) doc);
#line 44 "SerializablePropertyFloatTest.vala"
		_tmp5_ = _tmp4_;
#line 44 "SerializablePropertyFloatTest.vala"
		_tmp6_ = g_strconcat ("XML:\n", _tmp5_, NULL);
#line 44 "SerializablePropertyFloatTest.vala"
		_tmp7_ = _tmp6_;
#line 44 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp7_);
#line 44 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp7_);
#line 44 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp5_);
#line 45 "SerializablePropertyFloatTest.vala"
		_tmp8_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 45 "SerializablePropertyFloatTest.vala"
		_tmp9_ = _tmp8_;
#line 45 "SerializablePropertyFloatTest.vala"
		_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp9_) : NULL;
#line 45 "SerializablePropertyFloatTest.vala"
		if (_tmp10_ == NULL) {
#line 45 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (_tmp9_);
#line 234 "SerializablePropertyFloatTest.c"
		}
#line 45 "SerializablePropertyFloatTest.vala"
		element = _tmp10_;
#line 46 "SerializablePropertyFloatTest.vala"
		_tmp11_ = gxml_element_get_attr (element, "FloatValue");
#line 46 "SerializablePropertyFloatTest.vala"
		b = _tmp11_;
#line 47 "SerializablePropertyFloatTest.vala"
		_vala_assert (b == NULL, "b == null");
#line 48 "SerializablePropertyFloatTest.vala"
		_tmp12_ = gxml_element_get_attr (element, "name");
#line 48 "SerializablePropertyFloatTest.vala"
		s = _tmp12_;
#line 49 "SerializablePropertyFloatTest.vala"
		_vala_assert (s == NULL, "s == null");
#line 40 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (s);
#line 40 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (b);
#line 40 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (element);
#line 40 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (doc);
#line 40 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (bn);
#line 260 "SerializablePropertyFloatTest.c"
	}
	goto __finally297;
	__catch297_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp13_;
		const gchar* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
#line 40 "SerializablePropertyFloatTest.vala"
		e = _inner_error0_;
#line 40 "SerializablePropertyFloatTest.vala"
		_inner_error0_ = NULL;
#line 51 "SerializablePropertyFloatTest.vala"
		_tmp13_ = e->message;
#line 51 "SerializablePropertyFloatTest.vala"
		_tmp14_ = string_to_string (_tmp13_);
#line 51 "SerializablePropertyFloatTest.vala"
		_tmp15_ = g_strconcat ("ERROR: ", _tmp14_, NULL);
#line 51 "SerializablePropertyFloatTest.vala"
		_tmp16_ = _tmp15_;
#line 51 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp16_);
#line 51 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp16_);
#line 52 "SerializablePropertyFloatTest.vala"
		g_assert_not_reached ();
#line 40 "SerializablePropertyFloatTest.vala"
		_g_error_free0 (e);
#line 290 "SerializablePropertyFloatTest.c"
	}
	__finally297:
#line 40 "SerializablePropertyFloatTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 40 "SerializablePropertyFloatTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 40 "SerializablePropertyFloatTest.vala"
		g_clear_error (&_inner_error0_);
#line 40 "SerializablePropertyFloatTest.vala"
		return;
#line 301 "SerializablePropertyFloatTest.c"
	}
}

static void
___lambda243__gtest_func (void)
{
#line 38 "SerializablePropertyFloatTest.vala"
	__lambda243_ ();
#line 310 "SerializablePropertyFloatTest.c"
}

static gdouble
double_parse (const gchar* str)
{
	gdouble result = 0.0;
#line 944 "glib-2.0.vapi"
	g_return_val_if_fail (str != NULL, 0.0);
#line 945 "glib-2.0.vapi"
	result = g_ascii_strtod (str, NULL);
#line 945 "glib-2.0.vapi"
	return result;
#line 323 "SerializablePropertyFloatTest.c"
}

static void
__lambda244_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializablePropertyFloatTestFloatNode* bn = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp0_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_;
		SerializablePropertyFloatTestFloatNode* _tmp2_;
		GXmlGDocument* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlGDocument* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GXmlElement* element = NULL;
		GXmlGDocument* _tmp11_;
		GXmlNode* _tmp12_;
		GXmlNode* _tmp13_;
		GXmlElement* _tmp14_;
		GXmlNode* b = NULL;
		GXmlElement* _tmp15_;
		GXmlNode* _tmp16_;
		GXmlNode* _tmp17_;
		GXmlNode* s = NULL;
		GXmlElement* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlNode* _tmp20_;
		SerializablePropertyFloatTestFloatNode* _tmp21_;
		GXmlSerializableFloat* _tmp22_;
		GXmlSerializableFloat* _tmp23_;
		SerializablePropertyFloatTestFloatNode* _tmp24_;
		GXmlSerializableFloat* _tmp25_;
		GXmlSerializableFloat* _tmp26_;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp27_;
		SerializablePropertyFloatTestFloatNode* _tmp28_;
		GXmlGDocument* _tmp29_;
		GXmlNode* _tmp30_;
		GXmlNode* _tmp31_;
		GXmlGDocument* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
		GXmlElement* element2 = NULL;
		GXmlGDocument* _tmp37_;
		GXmlNode* _tmp38_;
		GXmlNode* _tmp39_;
		GXmlElement* _tmp40_;
		GXmlNode* b2 = NULL;
		GXmlElement* _tmp41_;
		GXmlNode* _tmp42_;
		GXmlNode* _tmp43_;
		SerializablePropertyFloatTestFloatNode* _tmp44_;
		GXmlSerializableFloat* _tmp45_;
		GXmlSerializableFloat* _tmp46_;
		GXmlNode* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
		gchar* _tmp51_;
		gchar* _tmp52_;
		SerializablePropertyFloatTestFloatNode* _tmp53_;
		GXmlSerializableFloat* _tmp54_;
		GXmlSerializableFloat* _tmp55_;
		gchar* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
		gchar* _tmp59_;
		GXmlNode* _tmp60_;
		gchar* _tmp61_;
		gchar* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
		gchar* _tmp65_;
		GXmlNode* _tmp66_;
		gchar* _tmp67_;
		gchar* _tmp68_;
		gchar* _tmp69_;
		gchar* _tmp70_;
		gchar* _tmp71_;
		GXmlNode* _tmp72_;
		gchar* _tmp73_;
		gchar* _tmp74_;
		gchar* _tmp75_;
		gchar* _tmp76_;
		gchar* _tmp77_;
		SerializablePropertyFloatTestFloatNode* _tmp78_;
		GXmlSerializableFloat* _tmp79_;
		GXmlSerializableFloat* _tmp80_;
		gchar* _tmp81_;
		gchar* _tmp82_;
		SerializablePropertyFloatTestFloatNode* _tmp83_;
		GXmlSerializableFloat* _tmp84_;
		GXmlSerializableFloat* _tmp85_;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp86_;
		SerializablePropertyFloatTestFloatNode* _tmp87_;
		GXmlGDocument* _tmp88_;
		GXmlNode* _tmp89_;
		GXmlNode* _tmp90_;
		GXmlGDocument* _tmp91_;
		gchar* _tmp92_;
		gchar* _tmp93_;
		gchar* _tmp94_;
		gchar* _tmp95_;
		GXmlElement* element3 = NULL;
		GXmlGDocument* _tmp96_;
		GXmlNode* _tmp97_;
		GXmlNode* _tmp98_;
		GXmlElement* _tmp99_;
		GXmlNode* b3 = NULL;
		GXmlElement* _tmp100_;
		GXmlNode* _tmp101_;
		GXmlNode* _tmp102_;
		GXmlNode* _tmp103_;
		gchar* _tmp104_;
		gchar* _tmp105_;
		gchar* _tmp106_;
		gchar* _tmp107_;
		gchar* _tmp108_;
		SerializablePropertyFloatTestFloatNode* _tmp109_;
		GXmlSerializableFloat* _tmp110_;
		GXmlSerializableFloat* _tmp111_;
		GXmlGDocument* doc4 = NULL;
		GXmlGDocument* _tmp112_;
		SerializablePropertyFloatTestFloatNode* _tmp113_;
		GXmlGDocument* _tmp114_;
		GXmlNode* _tmp115_;
		GXmlNode* _tmp116_;
		GXmlGDocument* _tmp117_;
		gchar* _tmp118_;
		gchar* _tmp119_;
		gchar* _tmp120_;
		gchar* _tmp121_;
		GXmlElement* element4 = NULL;
		GXmlGDocument* _tmp122_;
		GXmlNode* _tmp123_;
		GXmlNode* _tmp124_;
		GXmlElement* _tmp125_;
		GXmlNode* b4 = NULL;
		GXmlNode* _tmp126_;
#line 58 "SerializablePropertyFloatTest.vala"
		_tmp0_ = serializable_property_float_test_float_node_new ();
#line 58 "SerializablePropertyFloatTest.vala"
		bn = _tmp0_;
#line 59 "SerializablePropertyFloatTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 59 "SerializablePropertyFloatTest.vala"
		doc = _tmp1_;
#line 60 "SerializablePropertyFloatTest.vala"
		_tmp2_ = bn;
#line 60 "SerializablePropertyFloatTest.vala"
		_tmp3_ = doc;
#line 60 "SerializablePropertyFloatTest.vala"
		_tmp4_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 60 "SerializablePropertyFloatTest.vala"
		_tmp5_ = _tmp4_;
#line 60 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (_tmp5_);
#line 60 "SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 60 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc);
#line 60 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (bn);
#line 496 "SerializablePropertyFloatTest.c"
			goto __catch298_g_error;
		}
#line 61 "SerializablePropertyFloatTest.vala"
		_tmp6_ = doc;
#line 61 "SerializablePropertyFloatTest.vala"
		_tmp7_ = gxml_gnode_to_string ((GXmlGNode*) _tmp6_);
#line 61 "SerializablePropertyFloatTest.vala"
		_tmp8_ = _tmp7_;
#line 61 "SerializablePropertyFloatTest.vala"
		_tmp9_ = g_strconcat ("XML:\n", _tmp8_, NULL);
#line 61 "SerializablePropertyFloatTest.vala"
		_tmp10_ = _tmp9_;
#line 61 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp10_);
#line 61 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp10_);
#line 61 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp8_);
#line 62 "SerializablePropertyFloatTest.vala"
		_tmp11_ = doc;
#line 62 "SerializablePropertyFloatTest.vala"
		_tmp12_ = gxml_document_get_root ((GXmlDocument*) _tmp11_);
#line 62 "SerializablePropertyFloatTest.vala"
		_tmp13_ = _tmp12_;
#line 62 "SerializablePropertyFloatTest.vala"
		_tmp14_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp13_) : NULL;
#line 62 "SerializablePropertyFloatTest.vala"
		if (_tmp14_ == NULL) {
#line 62 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (_tmp13_);
#line 527 "SerializablePropertyFloatTest.c"
		}
#line 62 "SerializablePropertyFloatTest.vala"
		element = _tmp14_;
#line 63 "SerializablePropertyFloatTest.vala"
		_tmp15_ = element;
#line 63 "SerializablePropertyFloatTest.vala"
		_tmp16_ = gxml_element_get_attr (_tmp15_, "FloatValue");
#line 63 "SerializablePropertyFloatTest.vala"
		b = _tmp16_;
#line 64 "SerializablePropertyFloatTest.vala"
		_tmp17_ = b;
#line 64 "SerializablePropertyFloatTest.vala"
		_vala_assert (_tmp17_ == NULL, "b == null");
#line 65 "SerializablePropertyFloatTest.vala"
		_tmp18_ = element;
#line 65 "SerializablePropertyFloatTest.vala"
		_tmp19_ = gxml_element_get_attr (_tmp18_, "name");
#line 65 "SerializablePropertyFloatTest.vala"
		s = _tmp19_;
#line 66 "SerializablePropertyFloatTest.vala"
		_tmp20_ = s;
#line 66 "SerializablePropertyFloatTest.vala"
		_vala_assert (_tmp20_ == NULL, "s == null");
#line 68 "SerializablePropertyFloatTest.vala"
		_tmp21_ = bn;
#line 68 "SerializablePropertyFloatTest.vala"
		_tmp22_ = gxml_serializable_float_new ();
#line 68 "SerializablePropertyFloatTest.vala"
		_tmp23_ = _tmp22_;
#line 68 "SerializablePropertyFloatTest.vala"
		serializable_property_float_test_float_node_set_float_value (_tmp21_, _tmp23_);
#line 68 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (_tmp23_);
#line 70 "SerializablePropertyFloatTest.vala"
		_tmp24_ = bn;
#line 70 "SerializablePropertyFloatTest.vala"
		_tmp25_ = serializable_property_float_test_float_node_get_float_value (_tmp24_);
#line 70 "SerializablePropertyFloatTest.vala"
		_tmp26_ = _tmp25_;
#line 70 "SerializablePropertyFloatTest.vala"
		gxml_serializable_float_set_value (_tmp26_, (gfloat) 233.014);
#line 71 "SerializablePropertyFloatTest.vala"
		_tmp27_ = gxml_gdocument_new ();
#line 71 "SerializablePropertyFloatTest.vala"
		doc2 = _tmp27_;
#line 72 "SerializablePropertyFloatTest.vala"
		_tmp28_ = bn;
#line 72 "SerializablePropertyFloatTest.vala"
		_tmp29_ = doc2;
#line 72 "SerializablePropertyFloatTest.vala"
		_tmp30_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp28_, (GXmlNode*) _tmp29_, &_inner_error0_);
#line 72 "SerializablePropertyFloatTest.vala"
		_tmp31_ = _tmp30_;
#line 72 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (_tmp31_);
#line 72 "SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 72 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc2);
#line 72 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (s);
#line 72 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (b);
#line 72 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (element);
#line 72 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc);
#line 72 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (bn);
#line 597 "SerializablePropertyFloatTest.c"
			goto __catch298_g_error;
		}
#line 73 "SerializablePropertyFloatTest.vala"
		_tmp32_ = doc2;
#line 73 "SerializablePropertyFloatTest.vala"
		_tmp33_ = gxml_gnode_to_string ((GXmlGNode*) _tmp32_);
#line 73 "SerializablePropertyFloatTest.vala"
		_tmp34_ = _tmp33_;
#line 73 "SerializablePropertyFloatTest.vala"
		_tmp35_ = g_strconcat ("XML2:\n", _tmp34_, NULL);
#line 73 "SerializablePropertyFloatTest.vala"
		_tmp36_ = _tmp35_;
#line 73 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp36_);
#line 73 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp36_);
#line 73 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp34_);
#line 74 "SerializablePropertyFloatTest.vala"
		_tmp37_ = doc2;
#line 74 "SerializablePropertyFloatTest.vala"
		_tmp38_ = gxml_document_get_root ((GXmlDocument*) _tmp37_);
#line 74 "SerializablePropertyFloatTest.vala"
		_tmp39_ = _tmp38_;
#line 74 "SerializablePropertyFloatTest.vala"
		_tmp40_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp39_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp39_) : NULL;
#line 74 "SerializablePropertyFloatTest.vala"
		if (_tmp40_ == NULL) {
#line 74 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (_tmp39_);
#line 628 "SerializablePropertyFloatTest.c"
		}
#line 74 "SerializablePropertyFloatTest.vala"
		element2 = _tmp40_;
#line 75 "SerializablePropertyFloatTest.vala"
		_tmp41_ = element2;
#line 75 "SerializablePropertyFloatTest.vala"
		_tmp42_ = gxml_element_get_attr (_tmp41_, "FloatValue");
#line 75 "SerializablePropertyFloatTest.vala"
		b2 = _tmp42_;
#line 76 "SerializablePropertyFloatTest.vala"
		_tmp43_ = b2;
#line 76 "SerializablePropertyFloatTest.vala"
		_vala_assert (_tmp43_ != NULL, "b2 != null");
#line 77 "SerializablePropertyFloatTest.vala"
		_tmp44_ = bn;
#line 77 "SerializablePropertyFloatTest.vala"
		_tmp45_ = serializable_property_float_test_float_node_get_float_value (_tmp44_);
#line 77 "SerializablePropertyFloatTest.vala"
		_tmp46_ = _tmp45_;
#line 77 "SerializablePropertyFloatTest.vala"
		_vala_assert (gxml_serializable_float_get_value (_tmp46_) == ((gfloat) 233.014), "bn.float_value.get_value () == (float) 233.014");
#line 78 "SerializablePropertyFloatTest.vala"
		_tmp47_ = b2;
#line 78 "SerializablePropertyFloatTest.vala"
		_tmp48_ = gxml_node_get_value (_tmp47_);
#line 78 "SerializablePropertyFloatTest.vala"
		_tmp49_ = _tmp48_;
#line 78 "SerializablePropertyFloatTest.vala"
		_tmp50_ = _tmp49_;
#line 78 "SerializablePropertyFloatTest.vala"
		_tmp51_ = g_strconcat ("Value in xml: ", _tmp50_, NULL);
#line 78 "SerializablePropertyFloatTest.vala"
		_tmp52_ = _tmp51_;
#line 78 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp52_);
#line 78 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp52_);
#line 78 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp50_);
#line 79 "SerializablePropertyFloatTest.vala"
		_tmp53_ = bn;
#line 79 "SerializablePropertyFloatTest.vala"
		_tmp54_ = serializable_property_float_test_float_node_get_float_value (_tmp53_);
#line 79 "SerializablePropertyFloatTest.vala"
		_tmp55_ = _tmp54_;
#line 79 "SerializablePropertyFloatTest.vala"
		_tmp56_ = g_strdup_printf ("%g", gxml_serializable_float_get_value (_tmp55_));
#line 79 "SerializablePropertyFloatTest.vala"
		_tmp57_ = _tmp56_;
#line 79 "SerializablePropertyFloatTest.vala"
		_tmp58_ = g_strconcat ("Value in double class: ", _tmp57_, NULL);
#line 79 "SerializablePropertyFloatTest.vala"
		_tmp59_ = _tmp58_;
#line 79 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp59_);
#line 79 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp59_);
#line 79 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp57_);
#line 80 "SerializablePropertyFloatTest.vala"
		_tmp60_ = b2;
#line 80 "SerializablePropertyFloatTest.vala"
		_tmp61_ = gxml_node_get_value (_tmp60_);
#line 80 "SerializablePropertyFloatTest.vala"
		_tmp62_ = _tmp61_;
#line 80 "SerializablePropertyFloatTest.vala"
		_tmp63_ = _tmp62_;
#line 80 "SerializablePropertyFloatTest.vala"
		_tmp64_ = g_strdup_printf ("Value in xml formated %3.3f", double_parse (_tmp63_));
#line 80 "SerializablePropertyFloatTest.vala"
		_tmp65_ = _tmp64_;
#line 80 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp65_);
#line 80 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp65_);
#line 80 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp63_);
#line 81 "SerializablePropertyFloatTest.vala"
		_tmp66_ = b2;
#line 81 "SerializablePropertyFloatTest.vala"
		_tmp67_ = gxml_node_get_value (_tmp66_);
#line 81 "SerializablePropertyFloatTest.vala"
		_tmp68_ = _tmp67_;
#line 81 "SerializablePropertyFloatTest.vala"
		_tmp69_ = _tmp68_;
#line 81 "SerializablePropertyFloatTest.vala"
		_tmp70_ = g_strdup_printf ("%3.3f", double_parse (_tmp69_));
#line 81 "SerializablePropertyFloatTest.vala"
		_tmp71_ = _tmp70_;
#line 81 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp71_);
#line 81 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp71_);
#line 81 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp69_);
#line 82 "SerializablePropertyFloatTest.vala"
		_tmp72_ = b2;
#line 82 "SerializablePropertyFloatTest.vala"
		_tmp73_ = gxml_node_get_value (_tmp72_);
#line 82 "SerializablePropertyFloatTest.vala"
		_tmp74_ = _tmp73_;
#line 82 "SerializablePropertyFloatTest.vala"
		_tmp75_ = _tmp74_;
#line 82 "SerializablePropertyFloatTest.vala"
		_tmp76_ = g_strdup_printf ("%3.3f", double_parse (_tmp75_));
#line 82 "SerializablePropertyFloatTest.vala"
		_tmp77_ = _tmp76_;
#line 82 "SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp77_, "233.014") == 0, "\"%3.3f\".printf (double.parse (b2.value)) == \"233.014\"");
#line 82 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp77_);
#line 82 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp75_);
#line 83 "SerializablePropertyFloatTest.vala"
		_tmp78_ = bn;
#line 83 "SerializablePropertyFloatTest.vala"
		_tmp79_ = serializable_property_float_test_float_node_get_float_value (_tmp78_);
#line 83 "SerializablePropertyFloatTest.vala"
		_tmp80_ = _tmp79_;
#line 83 "SerializablePropertyFloatTest.vala"
		_tmp81_ = gxml_serializable_double_format ((GXmlSerializableDouble*) _tmp80_, "%3.3f");
#line 83 "SerializablePropertyFloatTest.vala"
		_tmp82_ = _tmp81_;
#line 83 "SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp82_, "233.014") == 0, "bn.float_value.format (\"%3.3f\") == \"233.014\"");
#line 83 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp82_);
#line 85 "SerializablePropertyFloatTest.vala"
		_tmp83_ = bn;
#line 85 "SerializablePropertyFloatTest.vala"
		_tmp84_ = serializable_property_float_test_float_node_get_float_value (_tmp83_);
#line 85 "SerializablePropertyFloatTest.vala"
		_tmp85_ = _tmp84_;
#line 85 "SerializablePropertyFloatTest.vala"
		gxml_serializable_float_set_value (_tmp85_, (gfloat) (-1.013));
#line 86 "SerializablePropertyFloatTest.vala"
		_tmp86_ = gxml_gdocument_new ();
#line 86 "SerializablePropertyFloatTest.vala"
		doc3 = _tmp86_;
#line 87 "SerializablePropertyFloatTest.vala"
		_tmp87_ = bn;
#line 87 "SerializablePropertyFloatTest.vala"
		_tmp88_ = doc3;
#line 87 "SerializablePropertyFloatTest.vala"
		_tmp89_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp87_, (GXmlNode*) _tmp88_, &_inner_error0_);
#line 87 "SerializablePropertyFloatTest.vala"
		_tmp90_ = _tmp89_;
#line 87 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (_tmp90_);
#line 87 "SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 87 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc3);
#line 87 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (b2);
#line 87 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (element2);
#line 87 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc2);
#line 87 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (s);
#line 87 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (b);
#line 87 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (element);
#line 87 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc);
#line 87 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (bn);
#line 798 "SerializablePropertyFloatTest.c"
			goto __catch298_g_error;
		}
#line 88 "SerializablePropertyFloatTest.vala"
		_tmp91_ = doc3;
#line 88 "SerializablePropertyFloatTest.vala"
		_tmp92_ = gxml_gnode_to_string ((GXmlGNode*) _tmp91_);
#line 88 "SerializablePropertyFloatTest.vala"
		_tmp93_ = _tmp92_;
#line 88 "SerializablePropertyFloatTest.vala"
		_tmp94_ = g_strconcat ("XML3:\n", _tmp93_, NULL);
#line 88 "SerializablePropertyFloatTest.vala"
		_tmp95_ = _tmp94_;
#line 88 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp95_);
#line 88 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp95_);
#line 88 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp93_);
#line 89 "SerializablePropertyFloatTest.vala"
		_tmp96_ = doc3;
#line 89 "SerializablePropertyFloatTest.vala"
		_tmp97_ = gxml_document_get_root ((GXmlDocument*) _tmp96_);
#line 89 "SerializablePropertyFloatTest.vala"
		_tmp98_ = _tmp97_;
#line 89 "SerializablePropertyFloatTest.vala"
		_tmp99_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp98_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp98_) : NULL;
#line 89 "SerializablePropertyFloatTest.vala"
		if (_tmp99_ == NULL) {
#line 89 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (_tmp98_);
#line 829 "SerializablePropertyFloatTest.c"
		}
#line 89 "SerializablePropertyFloatTest.vala"
		element3 = _tmp99_;
#line 90 "SerializablePropertyFloatTest.vala"
		_tmp100_ = element3;
#line 90 "SerializablePropertyFloatTest.vala"
		_tmp101_ = gxml_element_get_attr (_tmp100_, "FloatValue");
#line 90 "SerializablePropertyFloatTest.vala"
		b3 = _tmp101_;
#line 91 "SerializablePropertyFloatTest.vala"
		_tmp102_ = b3;
#line 91 "SerializablePropertyFloatTest.vala"
		_vala_assert (_tmp102_ != NULL, "b3 != null");
#line 92 "SerializablePropertyFloatTest.vala"
		_tmp103_ = b3;
#line 92 "SerializablePropertyFloatTest.vala"
		_tmp104_ = gxml_node_get_value (_tmp103_);
#line 92 "SerializablePropertyFloatTest.vala"
		_tmp105_ = _tmp104_;
#line 92 "SerializablePropertyFloatTest.vala"
		_tmp106_ = _tmp105_;
#line 92 "SerializablePropertyFloatTest.vala"
		_tmp107_ = g_strdup_printf ("%2.3f", double_parse (_tmp106_));
#line 92 "SerializablePropertyFloatTest.vala"
		_tmp108_ = _tmp107_;
#line 92 "SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp108_, "-1.013") == 0, "\"%2.3f\".printf (double.parse (b3.value)) == \"-1.013\"");
#line 92 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp108_);
#line 92 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp106_);
#line 94 "SerializablePropertyFloatTest.vala"
		_tmp109_ = bn;
#line 94 "SerializablePropertyFloatTest.vala"
		_tmp110_ = serializable_property_float_test_float_node_get_float_value (_tmp109_);
#line 94 "SerializablePropertyFloatTest.vala"
		_tmp111_ = _tmp110_;
#line 94 "SerializablePropertyFloatTest.vala"
		gxml_serializable_property_set_serializable_property_value ((GXmlSerializableProperty*) _tmp111_, NULL);
#line 95 "SerializablePropertyFloatTest.vala"
		_tmp112_ = gxml_gdocument_new ();
#line 95 "SerializablePropertyFloatTest.vala"
		doc4 = _tmp112_;
#line 96 "SerializablePropertyFloatTest.vala"
		_tmp113_ = bn;
#line 96 "SerializablePropertyFloatTest.vala"
		_tmp114_ = doc4;
#line 96 "SerializablePropertyFloatTest.vala"
		_tmp115_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp113_, (GXmlNode*) _tmp114_, &_inner_error0_);
#line 96 "SerializablePropertyFloatTest.vala"
		_tmp116_ = _tmp115_;
#line 96 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (_tmp116_);
#line 96 "SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 96 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc4);
#line 96 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (b3);
#line 96 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (element3);
#line 96 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc3);
#line 96 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (b2);
#line 96 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (element2);
#line 96 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc2);
#line 96 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (s);
#line 96 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (b);
#line 96 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (element);
#line 96 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc);
#line 96 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (bn);
#line 909 "SerializablePropertyFloatTest.c"
			goto __catch298_g_error;
		}
#line 97 "SerializablePropertyFloatTest.vala"
		_tmp117_ = doc4;
#line 97 "SerializablePropertyFloatTest.vala"
		_tmp118_ = gxml_gnode_to_string ((GXmlGNode*) _tmp117_);
#line 97 "SerializablePropertyFloatTest.vala"
		_tmp119_ = _tmp118_;
#line 97 "SerializablePropertyFloatTest.vala"
		_tmp120_ = g_strconcat ("XML3:\n", _tmp119_, NULL);
#line 97 "SerializablePropertyFloatTest.vala"
		_tmp121_ = _tmp120_;
#line 97 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp121_);
#line 97 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp121_);
#line 97 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp119_);
#line 98 "SerializablePropertyFloatTest.vala"
		_tmp122_ = doc4;
#line 98 "SerializablePropertyFloatTest.vala"
		_tmp123_ = gxml_document_get_root ((GXmlDocument*) _tmp122_);
#line 98 "SerializablePropertyFloatTest.vala"
		_tmp124_ = _tmp123_;
#line 98 "SerializablePropertyFloatTest.vala"
		_tmp125_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp124_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp124_) : NULL;
#line 98 "SerializablePropertyFloatTest.vala"
		if (_tmp125_ == NULL) {
#line 98 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (_tmp124_);
#line 940 "SerializablePropertyFloatTest.c"
		}
#line 98 "SerializablePropertyFloatTest.vala"
		element4 = _tmp125_;
#line 99 "SerializablePropertyFloatTest.vala"
		_tmp126_ = gxml_element_get_attr (element4, "FloatValue");
#line 99 "SerializablePropertyFloatTest.vala"
		b4 = _tmp126_;
#line 100 "SerializablePropertyFloatTest.vala"
		_vala_assert (b4 == NULL, "b4 == null");
#line 57 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (b4);
#line 57 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (element4);
#line 57 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (doc4);
#line 57 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (b3);
#line 57 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (element3);
#line 57 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (doc3);
#line 57 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (b2);
#line 57 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (element2);
#line 57 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (doc2);
#line 57 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (s);
#line 57 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (b);
#line 57 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (element);
#line 57 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (doc);
#line 57 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (bn);
#line 978 "SerializablePropertyFloatTest.c"
	}
	goto __finally298;
	__catch298_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp127_;
		const gchar* _tmp128_;
		gchar* _tmp129_;
		gchar* _tmp130_;
#line 57 "SerializablePropertyFloatTest.vala"
		e = _inner_error0_;
#line 57 "SerializablePropertyFloatTest.vala"
		_inner_error0_ = NULL;
#line 102 "SerializablePropertyFloatTest.vala"
		_tmp127_ = e->message;
#line 102 "SerializablePropertyFloatTest.vala"
		_tmp128_ = string_to_string (_tmp127_);
#line 102 "SerializablePropertyFloatTest.vala"
		_tmp129_ = g_strconcat ("ERROR: ", _tmp128_, NULL);
#line 102 "SerializablePropertyFloatTest.vala"
		_tmp130_ = _tmp129_;
#line 102 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp130_);
#line 102 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp130_);
#line 103 "SerializablePropertyFloatTest.vala"
		g_assert_not_reached ();
#line 57 "SerializablePropertyFloatTest.vala"
		_g_error_free0 (e);
#line 1008 "SerializablePropertyFloatTest.c"
	}
	__finally298:
#line 57 "SerializablePropertyFloatTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 57 "SerializablePropertyFloatTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 57 "SerializablePropertyFloatTest.vala"
		g_clear_error (&_inner_error0_);
#line 57 "SerializablePropertyFloatTest.vala"
		return;
#line 1019 "SerializablePropertyFloatTest.c"
	}
}

static void
___lambda244__gtest_func (void)
{
#line 55 "SerializablePropertyFloatTest.vala"
	__lambda244_ ();
#line 1028 "SerializablePropertyFloatTest.c"
}

static void
__lambda245_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp0_;
		SerializablePropertyFloatTestFloatNode* f = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp1_;
		SerializablePropertyFloatTestFloatNode* _tmp2_;
		GXmlGDocument* _tmp3_;
		SerializablePropertyFloatTestFloatNode* _tmp4_;
		GXmlSerializableFloat* _tmp5_;
		GXmlSerializableFloat* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		SerializablePropertyFloatTestFloatNode* _tmp11_;
		GXmlSerializableFloat* _tmp12_;
		GXmlSerializableFloat* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		SerializablePropertyFloatTestFloatNode* _tmp16_;
		GXmlSerializableFloat* _tmp17_;
		GXmlSerializableFloat* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
		SerializablePropertyFloatTestFloatNode* _tmp23_;
		GXmlSerializableFloat* _tmp24_;
		GXmlSerializableFloat* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
#line 109 "SerializablePropertyFloatTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <FloatNode FloatValue=\"3.1416\"/>", 0, &_inner_error0_);
#line 109 "SerializablePropertyFloatTest.vala"
		doc1 = _tmp0_;
#line 109 "SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1074 "SerializablePropertyFloatTest.c"
			goto __catch299_g_error;
		}
#line 111 "SerializablePropertyFloatTest.vala"
		_tmp1_ = serializable_property_float_test_float_node_new ();
#line 111 "SerializablePropertyFloatTest.vala"
		f = _tmp1_;
#line 112 "SerializablePropertyFloatTest.vala"
		_tmp2_ = f;
#line 112 "SerializablePropertyFloatTest.vala"
		_tmp3_ = doc1;
#line 112 "SerializablePropertyFloatTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 112 "SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 112 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (f);
#line 112 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc1);
#line 1093 "SerializablePropertyFloatTest.c"
			goto __catch299_g_error;
		}
#line 113 "SerializablePropertyFloatTest.vala"
		_tmp4_ = f;
#line 113 "SerializablePropertyFloatTest.vala"
		_tmp5_ = serializable_property_float_test_float_node_get_float_value (_tmp4_);
#line 113 "SerializablePropertyFloatTest.vala"
		_tmp6_ = _tmp5_;
#line 113 "SerializablePropertyFloatTest.vala"
		_tmp7_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp6_);
#line 113 "SerializablePropertyFloatTest.vala"
		_tmp8_ = _tmp7_;
#line 113 "SerializablePropertyFloatTest.vala"
		_tmp9_ = g_strconcat ("Actual value: ", _tmp8_, NULL);
#line 113 "SerializablePropertyFloatTest.vala"
		_tmp10_ = _tmp9_;
#line 113 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp10_);
#line 113 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp10_);
#line 113 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp8_);
#line 114 "SerializablePropertyFloatTest.vala"
		_tmp11_ = f;
#line 114 "SerializablePropertyFloatTest.vala"
		_tmp12_ = serializable_property_float_test_float_node_get_float_value (_tmp11_);
#line 114 "SerializablePropertyFloatTest.vala"
		_tmp13_ = _tmp12_;
#line 114 "SerializablePropertyFloatTest.vala"
		_tmp14_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp13_);
#line 114 "SerializablePropertyFloatTest.vala"
		_tmp15_ = _tmp14_;
#line 114 "SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp15_, "3.1416") == 0, "f.float_value.get_serializable_property_value () == \"3.1416\"");
#line 114 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp15_);
#line 115 "SerializablePropertyFloatTest.vala"
		_tmp16_ = f;
#line 115 "SerializablePropertyFloatTest.vala"
		_tmp17_ = serializable_property_float_test_float_node_get_float_value (_tmp16_);
#line 115 "SerializablePropertyFloatTest.vala"
		_tmp18_ = _tmp17_;
#line 115 "SerializablePropertyFloatTest.vala"
		_tmp19_ = g_strdup_printf ("%g", gxml_serializable_float_get_value (_tmp18_));
#line 115 "SerializablePropertyFloatTest.vala"
		_tmp20_ = _tmp19_;
#line 115 "SerializablePropertyFloatTest.vala"
		_tmp21_ = g_strconcat ("Actual value parse: ", _tmp20_, NULL);
#line 115 "SerializablePropertyFloatTest.vala"
		_tmp22_ = _tmp21_;
#line 115 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp22_);
#line 115 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp22_);
#line 115 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp20_);
#line 116 "SerializablePropertyFloatTest.vala"
		_tmp23_ = f;
#line 116 "SerializablePropertyFloatTest.vala"
		_tmp24_ = serializable_property_float_test_float_node_get_float_value (_tmp23_);
#line 116 "SerializablePropertyFloatTest.vala"
		_tmp25_ = _tmp24_;
#line 116 "SerializablePropertyFloatTest.vala"
		_tmp26_ = g_strdup_printf ("%2.4f", (gdouble) gxml_serializable_float_get_value (_tmp25_));
#line 116 "SerializablePropertyFloatTest.vala"
		_tmp27_ = _tmp26_;
#line 116 "SerializablePropertyFloatTest.vala"
		_tmp28_ = g_strdup_printf ("%2.4f", 3.1416);
#line 116 "SerializablePropertyFloatTest.vala"
		_tmp29_ = _tmp28_;
#line 116 "SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp27_, _tmp29_) == 0, "\"%2.4f\".printf (f.float_value.get_value ()) == \"%2.4f\".printf (3.1416)");
#line 116 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp29_);
#line 116 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp27_);
#line 108 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (f);
#line 108 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (doc1);
#line 1174 "SerializablePropertyFloatTest.c"
	}
	goto __finally299;
	__catch299_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp30_;
		const gchar* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
#line 108 "SerializablePropertyFloatTest.vala"
		e = _inner_error0_;
#line 108 "SerializablePropertyFloatTest.vala"
		_inner_error0_ = NULL;
#line 118 "SerializablePropertyFloatTest.vala"
		_tmp30_ = e->message;
#line 118 "SerializablePropertyFloatTest.vala"
		_tmp31_ = string_to_string (_tmp30_);
#line 118 "SerializablePropertyFloatTest.vala"
		_tmp32_ = g_strconcat ("ERROR: ", _tmp31_, NULL);
#line 118 "SerializablePropertyFloatTest.vala"
		_tmp33_ = _tmp32_;
#line 118 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp33_);
#line 118 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp33_);
#line 119 "SerializablePropertyFloatTest.vala"
		g_assert_not_reached ();
#line 108 "SerializablePropertyFloatTest.vala"
		_g_error_free0 (e);
#line 1204 "SerializablePropertyFloatTest.c"
	}
	__finally299:
#line 108 "SerializablePropertyFloatTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 108 "SerializablePropertyFloatTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 108 "SerializablePropertyFloatTest.vala"
		g_clear_error (&_inner_error0_);
#line 108 "SerializablePropertyFloatTest.vala"
		return;
#line 1215 "SerializablePropertyFloatTest.c"
	}
}

static void
___lambda245__gtest_func (void)
{
#line 106 "SerializablePropertyFloatTest.vala"
	__lambda245_ ();
#line 1224 "SerializablePropertyFloatTest.c"
}

static void
__lambda246_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp0_;
		SerializablePropertyFloatTestFloatNode* d = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp1_;
		SerializablePropertyFloatTestFloatNode* _tmp2_;
		GXmlGDocument* _tmp3_;
		SerializablePropertyFloatTestFloatNode* _tmp4_;
		GXmlSerializableFloat* _tmp5_;
		GXmlSerializableFloat* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		SerializablePropertyFloatTestFloatNode* _tmp11_;
		GXmlSerializableFloat* _tmp12_;
		GXmlSerializableFloat* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		SerializablePropertyFloatTestFloatNode* _tmp16_;
		GXmlSerializableFloat* _tmp17_;
		GXmlSerializableFloat* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		SerializablePropertyFloatTestFloatNode* _tmp25_;
		GXmlSerializableFloat* _tmp26_;
		GXmlSerializableFloat* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		gchar* _tmp31_;
		SerializablePropertyFloatTestFloatNode* _tmp32_;
		GXmlSerializableFloat* _tmp33_;
		GXmlSerializableFloat* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
		SerializablePropertyFloatTestFloatNode* _tmp37_;
		GXmlSerializableFloat* _tmp38_;
		GXmlSerializableFloat* _tmp39_;
		gchar* _tmp40_;
		gchar* _tmp41_;
		gchar* _tmp42_;
		gchar* _tmp43_;
#line 125 "SerializablePropertyFloatTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <FloatNode FloatValue=\"3.1416\"/>", 0, &_inner_error0_);
#line 125 "SerializablePropertyFloatTest.vala"
		doc1 = _tmp0_;
#line 125 "SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1284 "SerializablePropertyFloatTest.c"
			goto __catch300_g_error;
		}
#line 127 "SerializablePropertyFloatTest.vala"
		_tmp1_ = serializable_property_float_test_float_node_new ();
#line 127 "SerializablePropertyFloatTest.vala"
		d = _tmp1_;
#line 128 "SerializablePropertyFloatTest.vala"
		_tmp2_ = d;
#line 128 "SerializablePropertyFloatTest.vala"
		_tmp3_ = doc1;
#line 128 "SerializablePropertyFloatTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 128 "SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 128 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (d);
#line 128 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc1);
#line 1303 "SerializablePropertyFloatTest.c"
			goto __catch300_g_error;
		}
#line 129 "SerializablePropertyFloatTest.vala"
		_tmp4_ = d;
#line 129 "SerializablePropertyFloatTest.vala"
		_tmp5_ = serializable_property_float_test_float_node_get_float_value (_tmp4_);
#line 129 "SerializablePropertyFloatTest.vala"
		_tmp6_ = _tmp5_;
#line 129 "SerializablePropertyFloatTest.vala"
		_tmp7_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp6_);
#line 129 "SerializablePropertyFloatTest.vala"
		_tmp8_ = _tmp7_;
#line 129 "SerializablePropertyFloatTest.vala"
		_tmp9_ = g_strconcat ("Actual value: ", _tmp8_, NULL);
#line 129 "SerializablePropertyFloatTest.vala"
		_tmp10_ = _tmp9_;
#line 129 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp10_);
#line 129 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp10_);
#line 129 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp8_);
#line 130 "SerializablePropertyFloatTest.vala"
		_tmp11_ = d;
#line 130 "SerializablePropertyFloatTest.vala"
		_tmp12_ = serializable_property_float_test_float_node_get_float_value (_tmp11_);
#line 130 "SerializablePropertyFloatTest.vala"
		_tmp13_ = _tmp12_;
#line 130 "SerializablePropertyFloatTest.vala"
		_tmp14_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp13_);
#line 130 "SerializablePropertyFloatTest.vala"
		_tmp15_ = _tmp14_;
#line 130 "SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp15_, "3.1416") == 0, "d.float_value.get_serializable_property_value () == \"3.1416\"");
#line 130 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp15_);
#line 131 "SerializablePropertyFloatTest.vala"
		_tmp16_ = d;
#line 131 "SerializablePropertyFloatTest.vala"
		_tmp17_ = serializable_property_float_test_float_node_get_float_value (_tmp16_);
#line 131 "SerializablePropertyFloatTest.vala"
		_tmp18_ = _tmp17_;
#line 131 "SerializablePropertyFloatTest.vala"
		_tmp19_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp18_);
#line 131 "SerializablePropertyFloatTest.vala"
		_tmp20_ = _tmp19_;
#line 131 "SerializablePropertyFloatTest.vala"
		_tmp21_ = g_strdup_printf ("%2.4f", double_parse (_tmp20_));
#line 131 "SerializablePropertyFloatTest.vala"
		_tmp22_ = _tmp21_;
#line 131 "SerializablePropertyFloatTest.vala"
		_tmp23_ = g_strconcat ("Actual value parse: ", _tmp22_, NULL);
#line 131 "SerializablePropertyFloatTest.vala"
		_tmp24_ = _tmp23_;
#line 131 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp24_);
#line 131 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp24_);
#line 131 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp22_);
#line 131 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp20_);
#line 132 "SerializablePropertyFloatTest.vala"
		_tmp25_ = d;
#line 132 "SerializablePropertyFloatTest.vala"
		_tmp26_ = serializable_property_float_test_float_node_get_float_value (_tmp25_);
#line 132 "SerializablePropertyFloatTest.vala"
		_tmp27_ = _tmp26_;
#line 132 "SerializablePropertyFloatTest.vala"
		_tmp28_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp27_);
#line 132 "SerializablePropertyFloatTest.vala"
		_tmp29_ = _tmp28_;
#line 132 "SerializablePropertyFloatTest.vala"
		_tmp30_ = g_strdup_printf ("%2.4f", double_parse (_tmp29_));
#line 132 "SerializablePropertyFloatTest.vala"
		_tmp31_ = _tmp30_;
#line 132 "SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp31_, "3.1416") == 0, "\"%2.4f\".printf (double.parse (d.float_value.get_serializable_property_value ())) == \"3.1416\"");
#line 132 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp31_);
#line 132 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp29_);
#line 133 "SerializablePropertyFloatTest.vala"
		_tmp32_ = d;
#line 133 "SerializablePropertyFloatTest.vala"
		_tmp33_ = serializable_property_float_test_float_node_get_float_value (_tmp32_);
#line 133 "SerializablePropertyFloatTest.vala"
		_tmp34_ = _tmp33_;
#line 133 "SerializablePropertyFloatTest.vala"
		_tmp35_ = g_strdup_printf ("Value comparation: %2.4f", (gdouble) gxml_serializable_float_get_value (_tmp34_));
#line 133 "SerializablePropertyFloatTest.vala"
		_tmp36_ = _tmp35_;
#line 133 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp36_);
#line 133 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp36_);
#line 134 "SerializablePropertyFloatTest.vala"
		_tmp37_ = d;
#line 134 "SerializablePropertyFloatTest.vala"
		_tmp38_ = serializable_property_float_test_float_node_get_float_value (_tmp37_);
#line 134 "SerializablePropertyFloatTest.vala"
		_tmp39_ = _tmp38_;
#line 134 "SerializablePropertyFloatTest.vala"
		_tmp40_ = g_strdup_printf ("%2.4f", (gdouble) gxml_serializable_float_get_value (_tmp39_));
#line 134 "SerializablePropertyFloatTest.vala"
		_tmp41_ = _tmp40_;
#line 134 "SerializablePropertyFloatTest.vala"
		_tmp42_ = g_strdup_printf ("%2.4f", double_parse ("3.1416"));
#line 134 "SerializablePropertyFloatTest.vala"
		_tmp43_ = _tmp42_;
#line 134 "SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp41_, _tmp43_) == 0, "\"%2.4f\".printf (d.float_value.get_value ()) == \"%2.4f\".printf (double.parse (\"3.1416\"))");
#line 134 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp43_);
#line 134 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp41_);
#line 124 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (d);
#line 124 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (doc1);
#line 1424 "SerializablePropertyFloatTest.c"
	}
	goto __finally300;
	__catch300_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp44_;
		const gchar* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
#line 124 "SerializablePropertyFloatTest.vala"
		e = _inner_error0_;
#line 124 "SerializablePropertyFloatTest.vala"
		_inner_error0_ = NULL;
#line 136 "SerializablePropertyFloatTest.vala"
		_tmp44_ = e->message;
#line 136 "SerializablePropertyFloatTest.vala"
		_tmp45_ = string_to_string (_tmp44_);
#line 136 "SerializablePropertyFloatTest.vala"
		_tmp46_ = g_strconcat ("ERROR: ", _tmp45_, NULL);
#line 136 "SerializablePropertyFloatTest.vala"
		_tmp47_ = _tmp46_;
#line 136 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp47_);
#line 136 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp47_);
#line 137 "SerializablePropertyFloatTest.vala"
		g_assert_not_reached ();
#line 124 "SerializablePropertyFloatTest.vala"
		_g_error_free0 (e);
#line 1454 "SerializablePropertyFloatTest.c"
	}
	__finally300:
#line 124 "SerializablePropertyFloatTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 124 "SerializablePropertyFloatTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 124 "SerializablePropertyFloatTest.vala"
		g_clear_error (&_inner_error0_);
#line 124 "SerializablePropertyFloatTest.vala"
		return;
#line 1465 "SerializablePropertyFloatTest.c"
	}
}

static void
___lambda246__gtest_func (void)
{
#line 122 "SerializablePropertyFloatTest.vala"
	__lambda246_ ();
#line 1474 "SerializablePropertyFloatTest.c"
}

static void
__lambda247_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp0_;
		SerializablePropertyFloatTestFloatNode* d = NULL;
		SerializablePropertyFloatTestFloatNode* _tmp1_;
		SerializablePropertyFloatTestFloatNode* _tmp2_;
		GXmlGDocument* _tmp3_;
		SerializablePropertyFloatTestFloatNode* _tmp4_;
		GXmlSerializableFloat* _tmp5_;
		GXmlSerializableFloat* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		SerializablePropertyFloatTestFloatNode* _tmp11_;
		GXmlSerializableFloat* _tmp12_;
		GXmlSerializableFloat* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		SerializablePropertyFloatTestFloatNode* _tmp16_;
		GXmlSerializableFloat* _tmp17_;
		GXmlSerializableFloat* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		SerializablePropertyFloatTestFloatNode* _tmp25_;
		GXmlSerializableFloat* _tmp26_;
		GXmlSerializableFloat* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		gchar* _tmp31_;
#line 143 "SerializablePropertyFloatTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <FloatNode FloatValue=\"a\"/>", 0, &_inner_error0_);
#line 143 "SerializablePropertyFloatTest.vala"
		doc1 = _tmp0_;
#line 143 "SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1522 "SerializablePropertyFloatTest.c"
			goto __catch301_g_error;
		}
#line 145 "SerializablePropertyFloatTest.vala"
		_tmp1_ = serializable_property_float_test_float_node_new ();
#line 145 "SerializablePropertyFloatTest.vala"
		d = _tmp1_;
#line 146 "SerializablePropertyFloatTest.vala"
		_tmp2_ = d;
#line 146 "SerializablePropertyFloatTest.vala"
		_tmp3_ = doc1;
#line 146 "SerializablePropertyFloatTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 146 "SerializablePropertyFloatTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 146 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (d);
#line 146 "SerializablePropertyFloatTest.vala"
			_g_object_unref0 (doc1);
#line 1541 "SerializablePropertyFloatTest.c"
			goto __catch301_g_error;
		}
#line 147 "SerializablePropertyFloatTest.vala"
		_tmp4_ = d;
#line 147 "SerializablePropertyFloatTest.vala"
		_tmp5_ = serializable_property_float_test_float_node_get_float_value (_tmp4_);
#line 147 "SerializablePropertyFloatTest.vala"
		_tmp6_ = _tmp5_;
#line 147 "SerializablePropertyFloatTest.vala"
		_tmp7_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp6_);
#line 147 "SerializablePropertyFloatTest.vala"
		_tmp8_ = _tmp7_;
#line 147 "SerializablePropertyFloatTest.vala"
		_tmp9_ = g_strconcat ("Actual value: ", _tmp8_, NULL);
#line 147 "SerializablePropertyFloatTest.vala"
		_tmp10_ = _tmp9_;
#line 147 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp10_);
#line 147 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp10_);
#line 147 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp8_);
#line 148 "SerializablePropertyFloatTest.vala"
		_tmp11_ = d;
#line 148 "SerializablePropertyFloatTest.vala"
		_tmp12_ = serializable_property_float_test_float_node_get_float_value (_tmp11_);
#line 148 "SerializablePropertyFloatTest.vala"
		_tmp13_ = _tmp12_;
#line 148 "SerializablePropertyFloatTest.vala"
		_tmp14_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp13_);
#line 148 "SerializablePropertyFloatTest.vala"
		_tmp15_ = _tmp14_;
#line 148 "SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp15_, "a") == 0, "d.float_value.get_serializable_property_value () == \"a\"");
#line 148 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp15_);
#line 149 "SerializablePropertyFloatTest.vala"
		_tmp16_ = d;
#line 149 "SerializablePropertyFloatTest.vala"
		_tmp17_ = serializable_property_float_test_float_node_get_float_value (_tmp16_);
#line 149 "SerializablePropertyFloatTest.vala"
		_tmp18_ = _tmp17_;
#line 149 "SerializablePropertyFloatTest.vala"
		_tmp19_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp18_);
#line 149 "SerializablePropertyFloatTest.vala"
		_tmp20_ = _tmp19_;
#line 149 "SerializablePropertyFloatTest.vala"
		_tmp21_ = g_strdup_printf ("%2.4f", double_parse (_tmp20_));
#line 149 "SerializablePropertyFloatTest.vala"
		_tmp22_ = _tmp21_;
#line 149 "SerializablePropertyFloatTest.vala"
		_tmp23_ = g_strconcat ("Actual value parse: ", _tmp22_, NULL);
#line 149 "SerializablePropertyFloatTest.vala"
		_tmp24_ = _tmp23_;
#line 149 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp24_);
#line 149 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp24_);
#line 149 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp22_);
#line 149 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp20_);
#line 150 "SerializablePropertyFloatTest.vala"
		_tmp25_ = d;
#line 150 "SerializablePropertyFloatTest.vala"
		_tmp26_ = serializable_property_float_test_float_node_get_float_value (_tmp25_);
#line 150 "SerializablePropertyFloatTest.vala"
		_tmp27_ = _tmp26_;
#line 150 "SerializablePropertyFloatTest.vala"
		_tmp28_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp27_);
#line 150 "SerializablePropertyFloatTest.vala"
		_tmp29_ = _tmp28_;
#line 150 "SerializablePropertyFloatTest.vala"
		_tmp30_ = g_strdup_printf ("%2.4f", double_parse (_tmp29_));
#line 150 "SerializablePropertyFloatTest.vala"
		_tmp31_ = _tmp30_;
#line 150 "SerializablePropertyFloatTest.vala"
		_vala_assert (g_strcmp0 (_tmp31_, "0.0000") == 0, "\"%2.4f\".printf (double.parse (d.float_value.get_serializable_property_value ())) == \"0.0000\"");
#line 150 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp31_);
#line 150 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp29_);
#line 142 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (d);
#line 142 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (doc1);
#line 1628 "SerializablePropertyFloatTest.c"
	}
	goto __finally301;
	__catch301_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp32_;
		const gchar* _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
#line 142 "SerializablePropertyFloatTest.vala"
		e = _inner_error0_;
#line 142 "SerializablePropertyFloatTest.vala"
		_inner_error0_ = NULL;
#line 152 "SerializablePropertyFloatTest.vala"
		_tmp32_ = e->message;
#line 152 "SerializablePropertyFloatTest.vala"
		_tmp33_ = string_to_string (_tmp32_);
#line 152 "SerializablePropertyFloatTest.vala"
		_tmp34_ = g_strconcat ("ERROR: ", _tmp33_, NULL);
#line 152 "SerializablePropertyFloatTest.vala"
		_tmp35_ = _tmp34_;
#line 152 "SerializablePropertyFloatTest.vala"
		g_test_message ("%s", _tmp35_);
#line 152 "SerializablePropertyFloatTest.vala"
		_g_free0 (_tmp35_);
#line 153 "SerializablePropertyFloatTest.vala"
		g_assert_not_reached ();
#line 142 "SerializablePropertyFloatTest.vala"
		_g_error_free0 (e);
#line 1658 "SerializablePropertyFloatTest.c"
	}
	__finally301:
#line 142 "SerializablePropertyFloatTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 142 "SerializablePropertyFloatTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 142 "SerializablePropertyFloatTest.vala"
		g_clear_error (&_inner_error0_);
#line 142 "SerializablePropertyFloatTest.vala"
		return;
#line 1669 "SerializablePropertyFloatTest.c"
	}
}

static void
___lambda247__gtest_func (void)
{
#line 140 "SerializablePropertyFloatTest.vala"
	__lambda247_ ();
#line 1678 "SerializablePropertyFloatTest.c"
}

void
serializable_property_float_test_add_tests (void)
{
#line 38 "SerializablePropertyFloatTest.vala"
	g_test_add_func ("/gxml/serializable/Float/basic", ___lambda243__gtest_func);
#line 55 "SerializablePropertyFloatTest.vala"
	g_test_add_func ("/gxml/serializable/Float/changes", ___lambda244__gtest_func);
#line 106 "SerializablePropertyFloatTest.vala"
	g_test_add_func ("/gxml/serializable/Float/deserialize/basic", ___lambda245__gtest_func);
#line 122 "SerializablePropertyFloatTest.vala"
	g_test_add_func ("/gxml/serializable/Float/deserialize/aditional", ___lambda246__gtest_func);
#line 140 "SerializablePropertyFloatTest.vala"
	g_test_add_func ("/gxml/serializable/Float/deserialize/bad-value", ___lambda247__gtest_func);
#line 1694 "SerializablePropertyFloatTest.c"
}

SerializablePropertyFloatTest*
serializable_property_float_test_construct (GType object_type)
{
	SerializablePropertyFloatTest* self = NULL;
#line 27 "SerializablePropertyFloatTest.vala"
	self = (SerializablePropertyFloatTest*) gxml_test_construct (object_type);
#line 27 "SerializablePropertyFloatTest.vala"
	return self;
#line 1705 "SerializablePropertyFloatTest.c"
}

SerializablePropertyFloatTest*
serializable_property_float_test_new (void)
{
#line 27 "SerializablePropertyFloatTest.vala"
	return serializable_property_float_test_construct (TYPE_SERIALIZABLE_PROPERTY_FLOAT_TEST);
#line 1713 "SerializablePropertyFloatTest.c"
}

static inline gpointer
serializable_property_float_test_float_node_get_instance_private (SerializablePropertyFloatTestFloatNode* self)
{
	return G_STRUCT_MEMBER_P (self, SerializablePropertyFloatTestFloatNode_private_offset);
}

static gchar*
serializable_property_float_test_float_node_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializablePropertyFloatTestFloatNode * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 33 "SerializablePropertyFloatTest.vala"
	self = (SerializablePropertyFloatTestFloatNode*) base;
#line 33 "SerializablePropertyFloatTest.vala"
	_tmp0_ = g_strdup ("FloatNode");
#line 33 "SerializablePropertyFloatTest.vala"
	result = _tmp0_;
#line 33 "SerializablePropertyFloatTest.vala"
	return result;
#line 1736 "SerializablePropertyFloatTest.c"
}

static gchar*
serializable_property_float_test_float_node_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializablePropertyFloatTestFloatNode * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 34 "SerializablePropertyFloatTest.vala"
	self = (SerializablePropertyFloatTestFloatNode*) base;
#line 34 "SerializablePropertyFloatTest.vala"
	_tmp0_ = g_type_name (G_TYPE_FROM_INSTANCE ((GObject*) self));
#line 34 "SerializablePropertyFloatTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 34 "SerializablePropertyFloatTest.vala"
	result = _tmp1_;
#line 34 "SerializablePropertyFloatTest.vala"
	return result;
#line 1756 "SerializablePropertyFloatTest.c"
}

static gboolean
serializable_property_float_test_float_node_real_property_use_nick (GXmlSerializableObjectModel* base)
{
	SerializablePropertyFloatTestFloatNode * self;
	gboolean result = FALSE;
#line 35 "SerializablePropertyFloatTest.vala"
	self = (SerializablePropertyFloatTestFloatNode*) base;
#line 35 "SerializablePropertyFloatTest.vala"
	result = TRUE;
#line 35 "SerializablePropertyFloatTest.vala"
	return result;
#line 1770 "SerializablePropertyFloatTest.c"
}

SerializablePropertyFloatTestFloatNode*
serializable_property_float_test_float_node_construct (GType object_type)
{
	SerializablePropertyFloatTestFloatNode * self = NULL;
#line 28 "SerializablePropertyFloatTest.vala"
	self = (SerializablePropertyFloatTestFloatNode*) gxml_serializable_object_model_construct (object_type);
#line 28 "SerializablePropertyFloatTest.vala"
	return self;
#line 1781 "SerializablePropertyFloatTest.c"
}

SerializablePropertyFloatTestFloatNode*
serializable_property_float_test_float_node_new (void)
{
#line 28 "SerializablePropertyFloatTest.vala"
	return serializable_property_float_test_float_node_construct (SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE);
#line 1789 "SerializablePropertyFloatTest.c"
}

GXmlSerializableFloat*
serializable_property_float_test_float_node_get_float_value (SerializablePropertyFloatTestFloatNode* self)
{
	GXmlSerializableFloat* result;
	GXmlSerializableFloat* _tmp0_;
#line 31 "SerializablePropertyFloatTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 31 "SerializablePropertyFloatTest.vala"
	_tmp0_ = self->priv->_float_value;
#line 31 "SerializablePropertyFloatTest.vala"
	result = _tmp0_;
#line 31 "SerializablePropertyFloatTest.vala"
	return result;
#line 1805 "SerializablePropertyFloatTest.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 31 "SerializablePropertyFloatTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 1813 "SerializablePropertyFloatTest.c"
}

void
serializable_property_float_test_float_node_set_float_value (SerializablePropertyFloatTestFloatNode* self,
                                                             GXmlSerializableFloat* value)
{
#line 31 "SerializablePropertyFloatTest.vala"
	g_return_if_fail (self != NULL);
#line 31 "SerializablePropertyFloatTest.vala"
	if (serializable_property_float_test_float_node_get_float_value (self) != value) {
#line 1824 "SerializablePropertyFloatTest.c"
		GXmlSerializableFloat* _tmp0_;
#line 31 "SerializablePropertyFloatTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 31 "SerializablePropertyFloatTest.vala"
		_g_object_unref0 (self->priv->_float_value);
#line 31 "SerializablePropertyFloatTest.vala"
		self->priv->_float_value = _tmp0_;
#line 31 "SerializablePropertyFloatTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_property_float_test_float_node_properties[SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_FLOAT_VALUE_PROPERTY]);
#line 1834 "SerializablePropertyFloatTest.c"
	}
}

const gchar*
serializable_property_float_test_float_node_get_name (SerializablePropertyFloatTestFloatNode* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 32 "SerializablePropertyFloatTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 32 "SerializablePropertyFloatTest.vala"
	_tmp0_ = self->priv->_name;
#line 32 "SerializablePropertyFloatTest.vala"
	result = _tmp0_;
#line 32 "SerializablePropertyFloatTest.vala"
	return result;
#line 1851 "SerializablePropertyFloatTest.c"
}

void
serializable_property_float_test_float_node_set_name (SerializablePropertyFloatTestFloatNode* self,
                                                      const gchar* value)
{
#line 32 "SerializablePropertyFloatTest.vala"
	g_return_if_fail (self != NULL);
#line 32 "SerializablePropertyFloatTest.vala"
	if (g_strcmp0 (value, serializable_property_float_test_float_node_get_name (self)) != 0) {
#line 1862 "SerializablePropertyFloatTest.c"
		gchar* _tmp0_;
#line 32 "SerializablePropertyFloatTest.vala"
		_tmp0_ = g_strdup (value);
#line 32 "SerializablePropertyFloatTest.vala"
		_g_free0 (self->priv->_name);
#line 32 "SerializablePropertyFloatTest.vala"
		self->priv->_name = _tmp0_;
#line 32 "SerializablePropertyFloatTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_property_float_test_float_node_properties[SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_NAME_PROPERTY]);
#line 1872 "SerializablePropertyFloatTest.c"
	}
}

static void
serializable_property_float_test_float_node_class_init (SerializablePropertyFloatTestFloatNodeClass * klass,
                                                        gpointer klass_data)
{
#line 28 "SerializablePropertyFloatTest.vala"
	serializable_property_float_test_float_node_parent_class = g_type_class_peek_parent (klass);
#line 28 "SerializablePropertyFloatTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializablePropertyFloatTestFloatNode_private_offset);
#line 28 "SerializablePropertyFloatTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_property_float_test_float_node_real_node_name;
#line 28 "SerializablePropertyFloatTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_property_float_test_float_node_real_to_string;
#line 28 "SerializablePropertyFloatTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->property_use_nick = (gboolean (*) (GXmlSerializableObjectModel*)) serializable_property_float_test_float_node_real_property_use_nick;
#line 28 "SerializablePropertyFloatTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_property_float_test_float_node_get_property;
#line 28 "SerializablePropertyFloatTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_property_float_test_float_node_set_property;
#line 28 "SerializablePropertyFloatTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_property_float_test_float_node_finalize;
#line 28 "SerializablePropertyFloatTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_FLOAT_VALUE_PROPERTY, serializable_property_float_test_float_node_properties[SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_FLOAT_VALUE_PROPERTY] = g_param_spec_object ("float-value", "FloatValue", "float-value", GXML_TYPE_SERIALIZABLE_FLOAT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 28 "SerializablePropertyFloatTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_NAME_PROPERTY, serializable_property_float_test_float_node_properties[SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1900 "SerializablePropertyFloatTest.c"
}

static void
serializable_property_float_test_float_node_instance_init (SerializablePropertyFloatTestFloatNode * self,
                                                           gpointer klass)
{
#line 28 "SerializablePropertyFloatTest.vala"
	self->priv = serializable_property_float_test_float_node_get_instance_private (self);
#line 1909 "SerializablePropertyFloatTest.c"
}

static void
serializable_property_float_test_float_node_finalize (GObject * obj)
{
	SerializablePropertyFloatTestFloatNode * self;
#line 28 "SerializablePropertyFloatTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE, SerializablePropertyFloatTestFloatNode);
#line 31 "SerializablePropertyFloatTest.vala"
	_g_object_unref0 (self->priv->_float_value);
#line 32 "SerializablePropertyFloatTest.vala"
	_g_free0 (self->priv->_name);
#line 28 "SerializablePropertyFloatTest.vala"
	G_OBJECT_CLASS (serializable_property_float_test_float_node_parent_class)->finalize (obj);
#line 1924 "SerializablePropertyFloatTest.c"
}

GType
serializable_property_float_test_float_node_get_type (void)
{
	static volatile gsize serializable_property_float_test_float_node_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_float_test_float_node_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyFloatTestFloatNodeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_float_test_float_node_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyFloatTestFloatNode), 0, (GInstanceInitFunc) serializable_property_float_test_float_node_instance_init, NULL };
		GType serializable_property_float_test_float_node_type_id;
		serializable_property_float_test_float_node_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializablePropertyFloatTestFloatNode", &g_define_type_info, 0);
		SerializablePropertyFloatTestFloatNode_private_offset = g_type_add_instance_private (serializable_property_float_test_float_node_type_id, sizeof (SerializablePropertyFloatTestFloatNodePrivate));
		g_once_init_leave (&serializable_property_float_test_float_node_type_id__volatile, serializable_property_float_test_float_node_type_id);
	}
	return serializable_property_float_test_float_node_type_id__volatile;
}

static void
_vala_serializable_property_float_test_float_node_get_property (GObject * object,
                                                                guint property_id,
                                                                GValue * value,
                                                                GParamSpec * pspec)
{
	SerializablePropertyFloatTestFloatNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE, SerializablePropertyFloatTestFloatNode);
#line 28 "SerializablePropertyFloatTest.vala"
	switch (property_id) {
#line 28 "SerializablePropertyFloatTest.vala"
		case SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_FLOAT_VALUE_PROPERTY:
#line 28 "SerializablePropertyFloatTest.vala"
		g_value_set_object (value, serializable_property_float_test_float_node_get_float_value (self));
#line 28 "SerializablePropertyFloatTest.vala"
		break;
#line 28 "SerializablePropertyFloatTest.vala"
		case SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_NAME_PROPERTY:
#line 28 "SerializablePropertyFloatTest.vala"
		g_value_set_string (value, serializable_property_float_test_float_node_get_name (self));
#line 28 "SerializablePropertyFloatTest.vala"
		break;
#line 1963 "SerializablePropertyFloatTest.c"
		default:
#line 28 "SerializablePropertyFloatTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 28 "SerializablePropertyFloatTest.vala"
		break;
#line 1969 "SerializablePropertyFloatTest.c"
	}
}

static void
_vala_serializable_property_float_test_float_node_set_property (GObject * object,
                                                                guint property_id,
                                                                const GValue * value,
                                                                GParamSpec * pspec)
{
	SerializablePropertyFloatTestFloatNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_PROPERTY_FLOAT_TEST_TYPE_FLOAT_NODE, SerializablePropertyFloatTestFloatNode);
#line 28 "SerializablePropertyFloatTest.vala"
	switch (property_id) {
#line 28 "SerializablePropertyFloatTest.vala"
		case SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_FLOAT_VALUE_PROPERTY:
#line 28 "SerializablePropertyFloatTest.vala"
		serializable_property_float_test_float_node_set_float_value (self, g_value_get_object (value));
#line 28 "SerializablePropertyFloatTest.vala"
		break;
#line 28 "SerializablePropertyFloatTest.vala"
		case SERIALIZABLE_PROPERTY_FLOAT_TEST_FLOAT_NODE_NAME_PROPERTY:
#line 28 "SerializablePropertyFloatTest.vala"
		serializable_property_float_test_float_node_set_name (self, g_value_get_string (value));
#line 28 "SerializablePropertyFloatTest.vala"
		break;
#line 1995 "SerializablePropertyFloatTest.c"
		default:
#line 28 "SerializablePropertyFloatTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 28 "SerializablePropertyFloatTest.vala"
		break;
#line 2001 "SerializablePropertyFloatTest.c"
	}
}

static void
serializable_property_float_test_class_init (SerializablePropertyFloatTestClass * klass,
                                             gpointer klass_data)
{
#line 27 "SerializablePropertyFloatTest.vala"
	serializable_property_float_test_parent_class = g_type_class_peek_parent (klass);
#line 2011 "SerializablePropertyFloatTest.c"
}

static void
serializable_property_float_test_instance_init (SerializablePropertyFloatTest * self,
                                                gpointer klass)
{
}

/**
 *
 *  SerializablePropertyFloatTest.vala
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType
serializable_property_float_test_get_type (void)
{
	static volatile gsize serializable_property_float_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_float_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyFloatTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_float_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyFloatTest), 0, (GInstanceInitFunc) serializable_property_float_test_instance_init, NULL };
		GType serializable_property_float_test_type_id;
		serializable_property_float_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializablePropertyFloatTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_property_float_test_type_id__volatile, serializable_property_float_test_type_id);
	}
	return serializable_property_float_test_type_id__volatile;
}

